monkey.ci.api

Api functions, which can be invoked by build scripts. These often delegate to more specific namespaces, but this namespace is provided as a convenient entry point.

The general intention is to provide functions for most purposes, without the user having to resort to using keywords and maps.

Api functions, which can be invoked by build scripts.  These often delegate
to more specific namespaces, but this namespace is provided as a convenient
entry point.

The general intention is to provide functions for most purposes, without the user
having to resort to using keywords and maps.
raw docstring

monkey.ci.script.config

Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.

Build script configuration functions, used by the process controller to 
create a valid configuration that can then be read by the build script runner.
raw docstring

monkey.ci.script.edn

Functions for loading edn build scripts

Functions for loading edn build scripts
raw docstring

monkey.ci.script.interceptors

Babashka-compatible interceptor executor

Babashka-compatible interceptor executor
raw docstring

monkey.ci.script.json

Functions for loading json script files

Functions for loading json script files
raw docstring

monkey.ci.script.load

Script loading functionality

Script loading functionality
raw docstring

monkey.ci.script.yaml

Functions for loading yaml script files

Functions for loading yaml script files
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries