monkey.ci.script.api-client

Functions for invoking the build api HTTP server

Functions for invoking the build api HTTP server
raw docstring

accept-ednclj

(accept-edn req)
source

api-requestclj

(api-request {:keys [url token] :as opts} req)

Sends a request to the api at configured url

Sends a request to the api at configured url
sourceraw docstring

body->ednclj

(body->edn v)
source

build-paramsclj

Retrieves the params for this build. This fetches the parameters from the API, and adds to them any additional parameters that have been specified on the build itself. Since these are in encrypted form, we need to decrypt them here.

Retrieves the params for this build.  This fetches the parameters from the
API, and adds to them any additional parameters that have been specified on
the build itself.  Since these are in encrypted form, we need to decrypt
them here.
sourceraw docstring

ctx->api-clientclj

source

decrypt-keyclj

Given an encrypted data encryption key, decrypts it by sending a decryption request to the build api server.

Given an encrypted data encryption key, decrypts it by sending a decryption
request to the build api server.
sourceraw docstring

decrypt-key*clj

(decrypt-key* client enc-dek)
source

get-artifactclj

(get-artifact client job-id art-id dest)

Since scripts are often unable to unzip artifacts (e.g. if they run in babashka), downloading artifacts is not available. Instead we request the server to copy the desired files to a specified location.

Since scripts are often unable to unzip artifacts (e.g. if they run in babashka),
downloading artifacts is not available.  Instead we request the server to copy
the desired files to a specified location.
sourceraw docstring

get-cacheclj

(get-cache client job-id art-id dest)

Similar to get-artifact.

Similar to `get-artifact`.
sourceraw docstring

get-eventsclj

(get-events client)

Opens a stream that will receive all events for the build.

Opens a stream that will receive all events for the build.
sourceraw docstring

make-clientclj

(make-client opts)

Creates a new api client function for the given url. It returns a function that requires a request object that will send a http request. The function returns a result body. Options:

  • :url The url to connect to
  • :token The authentication token More options can be specified, they are directly passed to the request function.
Creates a new api client function for the given url.  It returns a function
that requires a request object that will send a http request.  The function 
returns a result body.  Options:
 - :url   The url to connect to
 - :token The authentication token
More options can be specified, they are directly passed to the request function.
sourceraw docstring

push-eventsclj

(push-events client evts)

Pushes events to the build api server, which is responsible for propagating them further up.

Pushes events to the build api server, which is responsible for propagating
them further up.
sourceraw docstring

put-artifactclj

(put-artifact client job-id art-id src)

Similar to get-artifact, does not actually upload the artifact but does instruct the server to copy the files at given path to artifact storage.

Similar to `get-artifact`, does not actually upload the artifact but does instruct
the server to copy the files at given path to artifact storage.
sourceraw docstring

put-cacheclj

(put-cache client job-id art-id src)

Similar to put-artifact

Similar to `put-artifact`
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries