monkey.ci.script.build

Build utility functions

Build utility functions
raw docstring

account->sidclj


add-warningclj

(add-warning r w)

checkout-dirclj

Gets the checkout dir as stored in the build structure

Gets the checkout dir as stored in the build structure
raw docstring

failed?clj

(failed? {:keys [status]})

failureclj


props->sidclj

Constructs sid from build properties

Constructs sid from build properties
raw docstring

scriptclj

Gets script from the build

Gets script from the build
raw docstring

script-dirclj

Gets script dir from the build

Gets script dir from the build
raw docstring

set-checkout-dirclj

(set-checkout-dir b d)

set-script-dirclj

(set-script-dir b d)

sidclj

Gets the sid from the build

Gets the sid from the build
raw docstring

sid-propsclj


skippedclj


skipped?clj

(skipped? {:keys [status]})

statusclj

(status v)

status?clj

(status? x)

Checks if the given object is a job status

Checks if the given object is a job status
raw docstring

successclj


success?clj

(success? {:keys [status]})

warningsclj

Gets result warnings

Gets result warnings
raw docstring

with-messageclj

(with-message r msg)

cljdoc builds & hosts documentation for Clojure/Script libraries