monkey.ci.script.config

Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.

Build script configuration functions, used by the process controller to 
create a valid configuration that can then be read by the build script runner.
raw docstring

apiclj


archsclj


buildclj


build->outclj

(build->out build)

default-parallellismclj


empty-configclj


job-filterclj


parallellismclj

The max number of concurrent jobs to run.

The max number of concurrent jobs to run.
raw docstring

resultclj


set-apiclj

(set-api c a)

set-archsclj

(set-archs c a)

set-buildclj

(set-build c b)

set-job-filterclj

(set-job-filter c f)

set-parallellismclj

(set-parallellism c p)

set-resultclj

(set-result c b)

cljdoc builds & hosts documentation for Clojure/Script libraries