monkey.ci.script.core

Main script running functionality.

Main script running functionality.
raw docstring

artifact-restorerclj

(artifact-restorer client)

Creates a function that is capable of restoring artifacts for action jobs.

Creates a function that is capable of restoring artifacts for action jobs.
raw docstring

artifact-saverclj

(artifact-saver client)

Creates a function that is capable of saving artifacts for action jobs.

Creates a function that is capable of saving artifacts for action jobs.
raw docstring

cache-restorerclj

(cache-restorer client)

Creates a function that is capable of restoring caches for action jobs.

Creates a function that is capable of restoring caches for action jobs.
raw docstring

cache-saverclj

(cache-saver client)

Creates a function that is capable of saving caches for action jobs.

Creates a function that is capable of saving caches for action jobs.
raw docstring

cli->confclj

(cli->conf args)

connect-eventsclj

(connect-events broker client)

run-bb-cliclj

(run-bb-cli cli-args)

Convenience function that allows a script to be executed from the command line (using babashka tasks). It reads command line args and converts it into a valid configuration.

Convenience function that allows a script to be executed from the command line 
(using babashka tasks).  It reads command line args and converts it into a valid
configuration.
raw docstring

run-clj-cliclj

(run-clj-cli {:keys [config]})

Provided as an entrypoint for clj invocations

Provided as an entrypoint for clj invocations
raw docstring

run-scriptclj

(run-script conf)

Loads and runs the build script using the given configuration, which contains details about where to find the files, how to connect to the build api, etc. Returns a channel that will hold the result of the build.

Loads and runs the build script using the given configuration, which contains
details about where to find the files, how to connect to the build api, etc.
Returns a channel that will hold the result of the build.
raw docstring

setup-runnerclj

(setup-runner conf)

cljdoc builds & hosts documentation for Clojure/Script libraries