monkey.ci.script.events

Mailman event handlers for scripts

Mailman event handlers for scripts
raw docstring

add-job-ctxclj

Interceptor that adds the job context, taken from state. An initial context should be already added to the state. Extensions may modify this context. It is passed to the jobs on execution.

Interceptor that adds the job context, taken from state.  An initial context should
be already added to the state.  Extensions may modify this context.  It is passed
to the jobs on execution.
raw docstring

add-job-retrieverclj

(add-job-retriever state)

Interceptor that augments the job context with an api function that can be used to retrieve other job details.

Interceptor that augments the job context with an api function that can be used to
retrieve other job details.
raw docstring

add-result-to-ctxclj

Adds the result from the event to the job context. Used by extensions.

Adds the result from the event to the job context.  Used by extensions.
raw docstring

build-canceledclj

(build-canceled ctx)

Marks all pending or blocked jobs in the script as skipped. If no other jobs remain, the script is ended.

Marks all pending or blocked jobs in the script as skipped.  If no other jobs remain,
the script is ended.
raw docstring

build-canceled?clj

(build-canceled? ctx)

build-sidclj


enqueue-jobsclj

Interceptor that enqueues all jobs indicated in the job/queued events in the result

Interceptor that enqueues all jobs indicated in the `job/queued` events in the result
raw docstring

execute-actionclj

Interceptor that executes the job in the input event in a new thread, provided it's an action job. The job context must contain all necessary components for the job to run properly, such as artifacts, cache and events.

Interceptor that executes the job in the input event in a new thread, provided
it's an action job.  The job context must contain all necessary components for 
the job to run properly, such as artifacts, cache and events.
raw docstring

get-api-clientclj


get-buildclj


get-eventsclj


get-initial-job-ctxclj


get-job-ctxclj

(get-job-ctx ctx)

Gets or creates a job context from the state for the current job.

Gets or creates a job context from the state for the current job.
raw docstring

get-job-filterclj


get-jobsclj


get-running-actionsclj


handle-script-errorclj

Marks script as failed

Marks script as failed
raw docstring

job-endclj

(job-end ctx)

Queues jobs that have their dependencies resolved, or ends the script if all jobs have been executed, or the build has been canceled. Blocked jobs are not queued, but marked as blocked.

Queues jobs that have their dependencies resolved, or ends the script
if all jobs have been executed, or the build has been canceled.  Blocked
jobs are not queued, but marked as blocked.
raw docstring

job-executedclj

(job-executed ctx)

Runs any extensions for the job in interceptors, then ends the job.

Runs any extensions for the job in interceptors, then ends the job.
raw docstring

job-idclj


job-queuedclj

(job-queued ctx)

Dispatches queued event for action or container job, depending on the type.

Dispatches queued event for action or container job, depending on the type.
raw docstring

job-unblockedclj

(job-unblocked ctx)

Received when a blocked job becomes unblocked: schedule it immediately.

Received when a blocked job becomes unblocked: schedule it immediately.
raw docstring

load-jobsclj

Interceptor that loads jobs from the location pointed to by the script-dir and adds them to the state.

Interceptor that loads jobs from the location pointed to by the script-dir 
and adds them to the state.
raw docstring

make-job-ctxclj

(make-job-ctx conf)

Constructs job context object from the route configuration

Constructs job context object from the route configuration
raw docstring

make-job-queued-evtclj

(make-job-queued-evt job build-sid)

make-routesclj

(make-routes {:keys [result] :as conf})

mark-canceledclj

Marks build as canceled, so no other jobs will be enqueued.

Marks build as canceled, so no other jobs will be enqueued.
raw docstring

put-resultclj

(put-result ch)

Interceptor that puts the result onto the result channel.

Interceptor that puts the result onto the result channel.
raw docstring

script-endclj

(script-end ctx)

script-initclj

(script-init ctx)

Loads all jobs in the build script, then starts the script

Loads all jobs in the build script, then starts the script
raw docstring

script-startclj

(script-start ctx)

Queues all jobs that have no dependencies

Queues all jobs that have no dependencies
raw docstring

set-buildclj

(set-build ctx build)

set-build-canceledclj

(set-build-canceled ctx)

set-eventsclj

(set-events ctx q)

set-initial-job-ctxclj

(set-initial-job-ctx ctx job-ctx)

set-job-ctxclj

(set-job-ctx ctx job-ctx)

set-job-resultclj

Sets job result according to the event

Sets job result according to the event
raw docstring

set-jobsclj

(set-jobs ctx jobs)

set-running-actionsclj

(set-running-actions ctx a)

update-jobclj

(update-job ctx job-id f & args)

Applies f to the job with given id in the state

Applies `f` to the job with given id in the state
raw docstring

update-job-initclj

Updates the job info with details from the job/initializing event

Updates the job info with details from the job/initializing event
raw docstring

with-absolute-job-dirclj

Updates the job working directory so it is an absolute path. This uses the current script working directory.

Updates the job working directory so it is an absolute path.  This uses the
current script working directory.
raw docstring

with-job-ctxclj

Adds job context from state in enter, and saves any updated context back on leave

Adds job context from state in `enter`, and saves any updated context back on `leave`
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries