monkey.ci.script.jobs


action-jobclj

(action-job id action)
(action-job id action opts)

Creates a new job

Creates a new job
raw docstring

action-job?clj


container-jobclj

(container-job id props)

Creates a job that executes in a container

Creates a job that executes in a container
raw docstring

container-job?clj


execute!clj

(execute! job ctx)

Executes the given action job. Posts start/end events to the broker provided in the context. Returns a channel that will hold the result.

Executes the given action job.  Posts start/end events to the broker provided in the
context.  Returns a channel that will hold the result.
raw docstring

execute-sync!clj

(execute-sync! job {:keys [mailman] :as ctx})

filter-jobsclj

(filter-jobs pred jobs)

Applies a filter to the given jobs, but includes all dependencies of jobs that match the filter, even though the dependencies themselves may not match it.

Applies a filter to the given jobs, but includes all dependencies of jobs that
match the filter, even though the dependencies themselves may not match it.
raw docstring

job-fn?clj

(job-fn? x)

job-idclj


job-typeclj


job-typesclj

Known job types

Known job types
raw docstring

job?clj

(job? x)

Checks if object is a job

Checks if object is a job
raw docstring

JobResolvablecljprotocol

Able to resolve into jobs (zero or more)

Able to resolve into jobs (zero or more)

resolve-jobsclj

(resolve-jobs x ctx)
raw docstring

make-job-dir-absoluteclj

(make-job-dir-absolute {:keys [job build] :as rt})

Rewrites the job dir in the context so it becomes an absolute path, calculated relative to the checkout dir.

Rewrites the job dir in the context so it becomes an absolute path, calculated
relative to the checkout dir.
raw docstring

next-jobsclj

(next-jobs jobs)

Returns a list of next jobs that are eligible for execution. If all jobs are pending, returns the starting jobs, those that don't have any dependencies.
Otherwise returns all pending jobs that have their dependencies fulfilled.

Returns a list of next jobs that are eligible for execution.  If all jobs are
pending, returns the starting jobs, those that don't have any dependencies.  
Otherwise returns all pending jobs that have their dependencies fulfilled.
raw docstring

resolvable?clj

(resolvable? x)

rt->contextclj

(rt->context rt)

cljdoc builds & hosts documentation for Clojure/Script libraries