monkey.ci.script.load

Script loading functionality

Script loading functionality
raw docstring

extensionsclj

Accepted script extensions, in order of processing

Accepted script extensions, in order of processing
raw docstring

load-jobsclj

(load-jobs build rt)

Loads the script and resolves the jobs

Loads the script and resolves the jobs
raw docstring

loadersclj

Script loader per extension

Script loader per extension
raw docstring

resolve-jobsclj

(resolve-jobs p rt)

The build script must return something that satisfies JobResolvable.
This function resolves the jobs by processing the script return value and assigns a generic id to the jobs that don't have one yet.

The build script must return something that satisfies `JobResolvable`.  
This function resolves the jobs by processing the script return value
and assigns a generic id to the jobs that don't have one yet.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries