(fn-name x)If x points to a fn, returns its name without namespace
If x points to a fn, returns its name without namespace
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |