Api functions, which can be invoked by build scripts. These often delegate to more specific namespaces, but this namespace is provided as a convenient entry point.
The general intention is to provide functions for most purposes, without the user having to resort to using keywords and maps.
Api functions, which can be invoked by build scripts. These often delegate to more specific namespaces, but this namespace is provided as a convenient entry point. The general intention is to provide functions for most purposes, without the user having to resort to using keywords and maps.
Functions for invoking the build api HTTP server
Functions for invoking the build api HTTP server
Build utility functions
Build utility functions
Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.
Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.
Main script running functionality.
Main script running functionality.
Functions for loading edn build scripts
Functions for loading edn build scripts
Mailman event handlers for scripts
Mailman event handlers for scripts
Babashka-compatible interceptor executor
Babashka-compatible interceptor executor
Functions for loading json script files
Functions for loading json script files
Script loading functionality
Script loading functionality
Functions for loading yaml script files
Functions for loading yaml script files
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |