Functions for invoking the build api HTTP server
Functions for invoking the build api HTTP server
(api-request {:keys [url token] :as opts} req)Sends a request to the api at configured url
Sends a request to the api at configured url
Retrieves the params for this build. This fetches the parameters from the API, and adds to them any additional parameters that have been specified on the build itself. Since these are in encrypted form, we need to decrypt them here.
Retrieves the params for this build. This fetches the parameters from the API, and adds to them any additional parameters that have been specified on the build itself. Since these are in encrypted form, we need to decrypt them here.
Given an encrypted data encryption key, decrypts it by sending a decryption request to the build api server.
Given an encrypted data encryption key, decrypts it by sending a decryption request to the build api server.
(get-artifact client job-id art-id dest)Since scripts are often unable to unzip artifacts (e.g. if they run in babashka), downloading artifacts is not available. Instead we request the server to copy the desired files to a specified location.
Since scripts are often unable to unzip artifacts (e.g. if they run in babashka), downloading artifacts is not available. Instead we request the server to copy the desired files to a specified location.
(get-cache client job-id art-id dest)Similar to get-artifact.
Similar to `get-artifact`.
(get-events client)Opens a stream that will receive all events for the build.
Opens a stream that will receive all events for the build.
(make-client opts)Creates a new api client function for the given url. It returns a function that requires a request object that will send a http request. The function returns a result body. Options:
Creates a new api client function for the given url. It returns a function that requires a request object that will send a http request. The function returns a result body. Options: - :url The url to connect to - :token The authentication token More options can be specified, they are directly passed to the request function.
(push-events client evts)Pushes events to the build api server, which is responsible for propagating them further up.
Pushes events to the build api server, which is responsible for propagating them further up.
(put-artifact client job-id art-id src)Similar to get-artifact, does not actually upload the artifact but does instruct
the server to copy the files at given path to artifact storage.
Similar to `get-artifact`, does not actually upload the artifact but does instruct the server to copy the files at given path to artifact storage.
(put-cache client job-id art-id src)Similar to put-artifact
Similar to `put-artifact`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |