Build utility functions
Build utility functions
(add-warning r w)Gets the checkout dir as stored in the build structure
Gets the checkout dir as stored in the build structure
(failed? {:keys [status]})Constructs sid from build properties
Constructs sid from build properties
(set-checkout-dir b d)(set-script-dir b d)(skipped? {:keys [status]})(status v)(status? x)Checks if the given object is a job status
Checks if the given object is a job status
(success? {:keys [status]})(with-message r msg)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |