monkey.ci.script.build

Build utility functions

Build utility functions
raw docstring

account->sidclj

source

add-warningclj

(add-warning r w)
source

checkout-dirclj

Gets the checkout dir as stored in the build structure

Gets the checkout dir as stored in the build structure
sourceraw docstring

failed?clj

(failed? {:keys [status]})
source

failureclj

source

props->sidclj

Constructs sid from build properties

Constructs sid from build properties
sourceraw docstring

scriptclj

Gets script from the build

Gets script from the build
sourceraw docstring

script-dirclj

Gets script dir from the build

Gets script dir from the build
sourceraw docstring

set-checkout-dirclj

(set-checkout-dir b d)
source

set-script-dirclj

(set-script-dir b d)
source

sidclj

Gets the sid from the build

Gets the sid from the build
sourceraw docstring

sid-propsclj

source

skippedclj

source

skipped?clj

(skipped? {:keys [status]})
source

statusclj

(status v)
source

status?clj

(status? x)

Checks if the given object is a job status

Checks if the given object is a job status
sourceraw docstring

successclj

source

success?clj

(success? {:keys [status]})
source

warningsclj

Gets result warnings

Gets result warnings
sourceraw docstring

with-messageclj

(with-message r msg)
source

cljdoc builds & hosts documentation for Clojure/Script libraries