Build utility functions
Build utility functions
Gets the checkout dir as stored in the build structure
Gets the checkout dir as stored in the build structure
Constructs sid from build properties
Constructs sid from build properties
(status? x)Checks if the given object is a job status
Checks if the given object is a job status
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |