Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.
Build script configuration functions, used by the process controller to create a valid configuration that can then be read by the build script runner.
(build->out build)The max number of concurrent jobs to run.
The max number of concurrent jobs to run.
(set-api c a)(set-archs c a)(set-build c b)(set-job-filter c f)(set-parallellism c p)(set-result c b)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |