Main script running functionality.
Main script running functionality.
(artifact-restorer client)Creates a function that is capable of restoring artifacts for action jobs.
Creates a function that is capable of restoring artifacts for action jobs.
(artifact-saver client)Creates a function that is capable of saving artifacts for action jobs.
Creates a function that is capable of saving artifacts for action jobs.
(cache-restorer client)Creates a function that is capable of restoring caches for action jobs.
Creates a function that is capable of restoring caches for action jobs.
(cache-saver client)Creates a function that is capable of saving caches for action jobs.
Creates a function that is capable of saving caches for action jobs.
(run-bb-cli cli-args)Convenience function that allows a script to be executed from the command line (using babashka tasks). It reads command line args and converts it into a valid configuration.
Convenience function that allows a script to be executed from the command line (using babashka tasks). It reads command line args and converts it into a valid configuration.
(run-clj-cli {:keys [config]})Provided as an entrypoint for clj invocations
Provided as an entrypoint for clj invocations
(run-script conf)Loads and runs the build script using the given configuration, which contains details about where to find the files, how to connect to the build api, etc. Returns a channel that will hold the result of the build.
Loads and runs the build script using the given configuration, which contains details about where to find the files, how to connect to the build api, etc. Returns a channel that will hold the result of the build.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |