monkey.ci.script.jobs


action-jobclj

(action-job id action)
(action-job id action opts)

Creates a new job

Creates a new job
sourceraw docstring

action-job?clj

source

container-jobclj

(container-job id props)

Creates a job that executes in a container

Creates a job that executes in a container
sourceraw docstring

container-job?clj

source

execute!clj

(execute! job ctx)

Executes the given action job. Posts start/end events to the broker provided in the context. Returns a channel that will hold the result.

Executes the given action job.  Posts start/end events to the broker provided in the
context.  Returns a channel that will hold the result.
sourceraw docstring

execute-sync!clj

(execute-sync! job {:keys [mailman] :as ctx})
source

filter-jobsclj

(filter-jobs pred jobs)

Applies a filter to the given jobs, but includes all dependencies of jobs that match the filter, even though the dependencies themselves may not match it.

Applies a filter to the given jobs, but includes all dependencies of jobs that
match the filter, even though the dependencies themselves may not match it.
sourceraw docstring

job-fn?clj

(job-fn? x)
source

job-idclj

source

job-typeclj

source

job-typesclj

Known job types

Known job types
sourceraw docstring

job?clj

(job? x)

Checks if object is a job

Checks if object is a job
sourceraw docstring

JobResolvablecljprotocol

Able to resolve into jobs (zero or more)

Able to resolve into jobs (zero or more)

resolve-jobsclj

(resolve-jobs x ctx)
sourceraw docstring

next-jobsclj

(next-jobs jobs)

Returns a list of next jobs that are eligible for execution. If all jobs are pending, returns the starting jobs, those that don't have any dependencies.
Otherwise returns all pending jobs that have their dependencies fulfilled.

Returns a list of next jobs that are eligible for execution.  If all jobs are
pending, returns the starting jobs, those that don't have any dependencies.  
Otherwise returns all pending jobs that have their dependencies fulfilled.
sourceraw docstring

resolvable?clj

(resolvable? x)
source

rt->contextclj

(rt->context rt)
source

cljdoc builds & hosts documentation for Clojure/Script libraries