(action-job id action)(action-job id action opts)Creates a new job
Creates a new job
(container-job id props)Creates a job that executes in a container
Creates a job that executes in a container
(execute! job ctx)Executes the given action job. Posts start/end events to the broker provided in the context. Returns a channel that will hold the result.
Executes the given action job. Posts start/end events to the broker provided in the context. Returns a channel that will hold the result.
(filter-jobs pred jobs)Applies a filter to the given jobs, but includes all dependencies of jobs that match the filter, even though the dependencies themselves may not match it.
Applies a filter to the given jobs, but includes all dependencies of jobs that match the filter, even though the dependencies themselves may not match it.
Able to resolve into jobs (zero or more)
Able to resolve into jobs (zero or more)
(resolve-jobs x ctx)(next-jobs jobs)Returns a list of next jobs that are eligible for execution. If all jobs are
pending, returns the starting jobs, those that don't have any dependencies.
Otherwise returns all pending jobs that have their dependencies fulfilled.
Returns a list of next jobs that are eligible for execution. If all jobs are pending, returns the starting jobs, those that don't have any dependencies. Otherwise returns all pending jobs that have their dependencies fulfilled.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |